@@ -4,8 +4,8 @@ Seed.import_namespace("Gio");
 
 // I don't think this is the right way of doing things.
 var r = new Gnio.Resolver();
-var sock = new Gnio.Socket({domain: Gnio.SocketDomain.Inet,
-						    type: Gnio.SocketType.Stream});
+var sock = new Gnio.Socket({domain: Gnio.SocketDomain.INET,
+						    type: Gnio.SocketType.STREAM});
 
 
 var addr = r.lookup_name("localhost");
@@ -27,7 +27,7 @@ os.put_string("Seed echo server. Type quit to quit.\n");
 while(1)
 {
 	var line = ds.read_line(null);
-    var cowsay = Seed.spawn("cowsay " + line);
+        var cowsay = Seed.spawn("cowsay " + line);
 	if (line.search("quit") > -1)
 	{
 		client.close();
