@@ -1,6 +1,6 @@
 #!/usr/bin/env seed
 
-Seed.import_namespace("Gtk");
+Gtk = imports.gi.Gtk;
 
 Gtk.init(null, null);
 
@@ -13,10 +13,10 @@ var packing = [
 		child: label,
 		fill: false,
 		padding: 10,
-		position: Gtk.PackType.End
+		position: Gtk.PackType.END
 	},
 	{
-		child:button,
+		child: button,
 		fill: false,
 		padding: 100,
 		expand: true
